@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2014-2023, Ilya Kotov <forkotov02@ya.ru>
+ * Copyright (c) 2014-2025, Ilya Kotov <forkotov02@ya.ru>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -63,9 +63,6 @@ class Qt5CTPlatformTheme : public QObject, public QPlatformTheme
 public:
     Qt5CTPlatformTheme();
 
-    virtual ~Qt5CTPlatformTheme();
-
-
     //virtual QPlatformMenuItem* createPlatformMenuItem() const;
     //virtual QPlatformMenu* createPlatformMenu() const;
 #ifdef GLOBAL_MENU
@@ -105,7 +102,7 @@ private:
 #endif
     QString loadStyleSheets(const QStringList &paths);
     QString m_style, m_iconTheme, m_userStyleSheet, m_prevStyleSheet;
-    QPalette *m_palette = nullptr;
+    QPalette m_palette;
     QFont m_generalFont, m_fixedFont;
     int m_doubleClickInterval;
     int m_cursorFlashTime;
@@ -113,7 +110,6 @@ private:
     int m_buttonBoxLayout;
     int m_keyboardScheme;
     bool m_update = false;
-    bool m_usePalette = true;
     int m_toolButtonStyle = Qt::ToolButtonFollowStyle;
     int m_wheelScrollLines = 3;
     bool m_showShortcutsInContextMenus = false;
